@@ -1,18 +1,19 @@
 /*****************************************************************************
-**  This is part of the g2 library
-**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
+**  Copyright (C) 1998-2001  Ljubomir Milanovic & Horst Wagner
+**  This file is part of the g2 library
 **
-**  This program is free software; you can redistribute it and/or modify
-**  it under the terms of the GNU General Public License (version 2) as
-**  published by the Free Software Foundation.
+**  This library is free software; you can redistribute it and/or
+**  modify it under the terms of the GNU Lesser General Public
+**  License as published by the Free Software Foundation; either
+**  version 2.1 of the License, or (at your option) any later version.
 **
-**  This program is distributed in the hope that it will be useful,
+**  This library is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
-**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-**  GNU General Public License for more details.
+**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+**  Lesser General Public License for more details.
 **
-**  You should have received a copy of the GNU General Public License
-**  along with this program; if not, write to the Free Software
+**  You should have received a copy of the GNU Lesser General Public
+**  License along with this library; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/
 #ifndef _G2_FUNIX_H
@@ -24,7 +25,7 @@
  *
  */
 
-#define G2_N_FUNIX  29	  /* WARNING !! */
+#define G2_N_FUNIX  30	  /* WARNING !! */
 			  /* number of funix excl. g2_FUNIX_NULL !!! */
 
 typedef enum g2_funix {
@@ -144,10 +145,14 @@ typedef enum g2_funix {
     g2_String,	          /* draw string */
 			  /* ... = (double)x, (double)y, (const char*)string */
 
-    g2_Image		  /* draw (pen) image */
+    g2_Image,		  /* draw (pen) image */
 			  /* ... = (double)x, (double)y,
 			           (int)x_size, (int)y_size, (int*)pen_array */
 
+    g2_QueryPointer	  /* query pointer position (mouse) */
+			  /* ... =  (double)*x, (double)*y,
+			            (unsigned int)*button */
+    
 } g2_funix;
 
 
